@@ -312,8 +312,8 @@ class ImgCompounder:
         self.__drawCameraBorderText()
         self.__drawCameraBorderLogo()
         self.__drawCameraLens()
-        # self.__to_cmyk()
         compound_result_data = {
+            'fileName': '%s.png' % self.compound_file_name,
             'path': self.compound_file_path,
             'url': '%s/%s/%s.png' % (self.compound_img_dir_url, self.history_id, self.compound_file_name)
         }
@@ -442,7 +442,7 @@ class ImgCompounder:
                             top = self.main_border_top
                             if main_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                top = self.main_border_top + (self.main_border_stroke_width - text_height) / 2 + 3
+                                top = self.main_border_top + (self.main_border_stroke_width - text_height) / 2
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if main_border_text['angle'] == 45:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -462,7 +462,7 @@ class ImgCompounder:
                                                      text_color=text_dict[text],
                                                      border_stroke_width=self.main_border_stroke_width)
                             left = self.main_border_left + self.main_border_width - self.main_border_stroke_width + \
-                                   (self.main_border_stroke_width - text_height) / 2 + 3
+                                   (self.main_border_stroke_width - text_height) / 2
                             top = self.main_border_top + main_border_text['top']
                             text_image = text_image.transpose(Image.ROTATE_270)
                             if main_border_text['flip'] == 1:
@@ -487,7 +487,7 @@ class ImgCompounder:
                                                      border_stroke_width=self.main_border_stroke_width)
                             left = self.main_border_left + main_border_text['left']
                             top = self.main_border_top + self.main_border_height - self.main_border_stroke_width + \
-                                  (self.main_border_stroke_width - text_height) / 2 + 3
+                                  (self.main_border_stroke_width - text_height) / 2
                             text_image = text_image.transpose(Image.ROTATE_180)
                             if main_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
@@ -515,7 +515,7 @@ class ImgCompounder:
                             text_image = text_image.transpose(Image.ROTATE_90)
                             if main_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                left =  self.main_border_left + (self.main_border_stroke_width - text_height) / 2 + 3
+                                left =  self.main_border_left + (self.main_border_stroke_width - text_height) / 2
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if main_border_text['angle'] == 315:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -735,7 +735,7 @@ class ImgCompounder:
                             top = 0 + self.camera_border_top
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                top = self.camera_border_top + (self.camera_border_stroke_width - text_height) / 2 + 5
+                                top = self.camera_border_top + (self.camera_border_stroke_width - text_height) / 2
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if camera_border_text['angle'] == 45:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -756,7 +756,7 @@ class ImgCompounder:
                                                      border_stroke_width=self.camera_border_stroke_width)
                             left = self.camera_border_width - self.camera_border_stroke_width + \
                                    (self.camera_border_stroke_width - text_height) / 2 + \
-                                   self.camera_border_left + 5
+                                   self.camera_border_left
                             top = camera_border_text['top'] + self.camera_border_top
                             text_image = text_image.transpose(Image.ROTATE_270)
                             if camera_border_text['flip'] == 1:
@@ -781,7 +781,7 @@ class ImgCompounder:
                                                      border_stroke_width=self.camera_border_stroke_width)
                             left = self.camera_border_left + camera_border_text['left']
                             top = self.camera_border_top + self.camera_border_height - self.camera_border_stroke_width + \
-                                  (self.camera_border_stroke_width - text_height) / 2 + 5
+                                  (self.camera_border_stroke_width - text_height) / 2
                             text_image = text_image.transpose(Image.ROTATE_180)
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
@@ -809,7 +809,7 @@ class ImgCompounder:
                             text_image = text_image.transpose(Image.ROTATE_90)
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                left = self.camera_border_left + (self.camera_border_stroke_width - text_height) / 2 + 5
+                                left = self.camera_border_left + (self.camera_border_stroke_width - text_height) / 2
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if camera_border_text['angle'] == 315:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -1009,7 +1009,7 @@ class ImgCompounder:
         text_draw = ImageDraw.Draw(text_image)
 
         bbox = text_draw.textbbox((0, 0), text, font=font)
-        text_height = bbox[3] - bbox[0]
+        text_height = bbox[3] - bbox[1]
 
         text_draw.text((0, 0), text, font=font, spacing=0, fill='#' + text_color, align='left', direction='ltr')
         return text_image, text_width, text_height
